"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataFromURL = exports.dataToEnv = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs"));
const path_1 = require("path");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const decrypt_1 = require("./decrypt");
const lib_1 = tslib_1.__importDefault(require("../lib"));
const dataToEnv = (data) => {
    if (!data.secret) {
        throw new Error('Invalid secret key');
    }
    const envFile = fs.createWriteStream((0, path_1.join)(process.cwd(), '.env'));
    const fileSecretKey = process.env.ENV_SECRET_KEY
        ? process.env.ENV_SECRET_KEY
        : fs.readFileSync((0, path_1.join)(process.cwd(), `${data.secret}`), 'utf8');
    if (data.file !== undefined) {
        const filePub = JSON.parse(fs.readFileSync((0, path_1.join)(process.cwd(), `${data.file}`), 'utf8').toString());
        const decryptedData = (0, decrypt_1.decryptData)(filePub.data, fileSecretKey);
        (0, lib_1.default)(decryptedData, envFile);
        console.log('Env was created from file');
    }
    else if (data.url !== undefined) {
        const urldata = (0, exports.dataFromURL)(data.url);
        urldata.then((data) => {
            const decryptedUrl = (0, decrypt_1.decryptData)(data.data, fileSecretKey);
            (0, lib_1.default)(decryptedUrl, envFile);
            console.log('Env was created from URL');
        });
    }
};
exports.dataToEnv = dataToEnv;
const dataFromURL = (url) => {
    const fetchData = (0, node_fetch_1.default)(url).then((response) => {
        if (response.status === 400) {
            throw new Error('File not found in specified URL');
        }
        return response.json().then((data) => {
            return data;
        });
    });
    return fetchData;
};
exports.dataFromURL = dataFromURL;
//# sourceMappingURL=env.js.map